MultiMethodMLEstimate-class: S4 object containing the results of multi-method ML accuracy...

MultiMethodMLEstimate-classR Documentation

S4 object containing the results of multi-method ML accuracy estimates

Description

S4 object containing the results of multi-method ML accuracy estimates

Slots

results

a list of estimated accuracy statistics

data

a matrix containing the raw data used for estimation

freqs

a vector containing the frequencies at which each row in data was observed

names

a list containing vectors of names of various dimensions

data

a copy of the data used to generate the estimated values

iter

an integer number of iterations needed for the EM algorithm to converge

prog

a list containing the values calculated during each iteration of the EM algorithm

type

a string describing the data type


emery documentation built on Feb. 23, 2026, 1:06 a.m.