Learn R Programming

emery (version 0.7.0)

new_boot_ML: Create new boot_ML class object

Description

Wrapper for creating boot_ML class object.

Usage

new_boot_ML(
  v_0,
  v_star,
  data,
  freqs = NULL,
  n_boot,
  n_study,
  max_iter,
  tol,
  n_obs,
  seed
)

Value

a boot_ML object

Arguments

v_0

MultiMethodMLEstimate S4 object

v_star

results slot of bootstrapped MultiMethodMLEstimate objects

data

An n_obs by n_method matrix containing the observed values for each method. If the dimensions are named, row names will be used to name each observation (obs_names) and column names will be used to name each measurement method (method_names).

freqs

A vector of elements n_obs long representing the number of times each row in data was observed. Used when data is a summary of unique response combinations.

n_boot

number of bootstrap estimates to compute

n_study

sample size to select for each bootstrap estimate

max_iter

The maximum number of EM algorithm iterations to compute before reporting a result.

tol

The minimum change in statistic estimates needed to continue iterating the EM algorithm.

n_obs

Number of observations in data

seed

optional seed for RNG