show-MultiMethodMLEstimate-method: Show a MultiMethodMLEstimate S4 object

show,MultiMethodMLEstimate-methodR Documentation

Show a MultiMethodMLEstimate S4 object

Description

Print the accuracy statistic estimates stored in a MultiMethodMLEstimate object.

Usage

## S4 method for signature 'MultiMethodMLEstimate'
show(object)

Arguments

object

An object of class MultiMethodMLEstimate.

Value

A list containing relevant accuracy statistic estimates. This is a subset of the list stored in results slot of the MultiMethodMLEstimate object.


emery documentation built on Feb. 23, 2026, 1:06 a.m.