unique_obs_summary: Reduce Data by Summarizing Observations

View source: R/utility_functions.R

unique_obs_summaryR Documentation

Reduce Data by Summarizing Observations

Description

Extract unique rows from a data frame. Collect row names of duplicate observations and frequencies of each.

Usage

unique_obs_summary(data)

Arguments

data

An n_obs by n_method matrix containing the observed values for each method. If the dimensions are named, row names will be used to name each observation (obs_names) and column names will be used to name each measurement method (method_names).

Value

list containing matrix of unique rows with names and frequencies of duplicates.


emery documentation built on Feb. 23, 2026, 1:06 a.m.