Wrapper for creating boot_ML class object.
new_boot_ML(
v_0,
v_star,
data,
freqs = NULL,
n_boot,
n_study,
max_iter,
tol,
n_obs,
seed
)a boot_ML object
MultiMethodMLEstimate S4 object
results slot of bootstrapped MultiMethodMLEstimate objects
An n_obs by n_method matrix containing the
observed values for each method. If the dimensions are named, row names will
be used to name each observation (obs_names) and column names will be used
to name each measurement method (method_names).
A vector of elements n_obs long representing the number of times
each row in data was observed. Used when data is a summary of unique response
combinations.
number of bootstrap estimates to compute
sample size to select for each bootstrap estimate
The maximum number of EM algorithm iterations to compute before reporting a result.
The minimum change in statistic estimates needed to continue iterating the EM algorithm.
Number of observations in data
optional seed for RNG