random_start() is a general function for creating a random, plausible starting point
for the EM algorithm to begin iterating from. Varying the starting points of repeated
calculations can help the researcher detect local extremes.
Creates random initial sensitivity and specificity values for n_method methods.
Values are generated from a random beta distribution with shape parameters
a=3 and b=1. Prevalence is a random value from a uniform distribution.
random_start(type, n_method, method_names)random_start_binary(n_method = NULL, method_names = NULL)
random_start_ordinal(n_method = NULL, method_names = NULL)
List containing initial values to be passed to init argument
A string specifying the data type of the methods being simulated.
An integer representing the number of methods to simulate.
Optional vector of names used to identify each method.