View source: R/utility_functions.R
| unique_obs_summary | R Documentation |
Extract unique rows from a data frame. Collect row names of duplicate observations and frequencies of each.
unique_obs_summary(data)
data |
An |
list containing matrix of unique rows with names and frequencies of duplicates.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.