Extract unique rows from a data frame. Collect row names of duplicate observations and frequencies of each.
unique_obs_summary(data)list containing matrix of unique rows with names and frequencies of duplicates.
An n_obs by n_method matrix containing the
observed values for each method. If the dimensions are named, row names will
be used to name each observation (obs_names) and column names will be used
to name each measurement method (method_names).